package sdk

type GoodsInfoRes struct {
	commonRes
	Data GoodsInsertReq `json:"data"`
}
type GetStockRes struct {
	commonRes
	Data []GetStock `json:"data"`
}
type GoodsCommonRes struct {
	commonRes
	Data string `json:"data"`
}
type CreateGoodsRes struct {
	commonRes
	Data struct {
		GoodsID int `json:"goodsId"`
	} `json:"data"`
}
type GoodsCollectRes struct {
	commonRes
	Data int `json:"data"`
}
type GoodsListRes struct {
	commonRes
	Data GoodsList `json:"data"`
}

type GoodsList struct {
	Count         int     `json:"count"`
	DelCount      int     `json:"del_count"`
	DownsaleCount int     `json:"downsale_count"`
	List          []Goods `json:"list"`
}

type Goods struct {
	GoodsId           uint    `json:"goods_id"`            // 商品ID
	GoodsName         string  `json:"goods_name"`          // 商品名称
	CategoryId        uint    `json:"category_id"`         // 商品类别ID
	DefaultImage      string  `json:"default_image"`       // 默认商品图片
	JsPrice           int     `json:"js_price"`            // 商家平台结算价格
	Price             int     `json:"price"`               // 现价
	ScPrice           int     `json:"sc_price"`            // 市场价
	GoodsNowStock     int     `json:"stock"`               // 当前库存
	AddTime           int     `json:"add_time"`            // 添加时间
	IsOn              int     `json:"is_on"`               //
	SellerId          int     `json:"seller_id"`           // 添加用户ID
	UpOnsale          int     `json:"up_onsale"`           // 申请上线 1:申请2:驳回
	IsOnsale          int     `json:"is_onsale"`           // 是否上架
	ProducingArea     string  `json:"producing_area"`      // 商品产地
	Weight            float64 `json:"weight"`              // 商品重量
	ProfitRate        float64 `json:"profit_rate"`         // 商品利润率
	AftersaleTime     int     `json:"aftersale_time"`      // 售后时长
	GoodsBrand        string  `json:"goods_brand"`         // 商品品牌
	Unit              string  `json:"unit"`                // 单位, 如: 个/件/包
	StoreName         string  `json:"store_name"`          // 店铺名称
	LastPerateContent string  `json:"last_perate_content"` // 最后审核内容
	ChannelName       string  `json:"channel_name"`
	ChannelId         int     `json:"channel_id"`
	OperateTime       int     `json:"operate_time"`
	PushStatus        int     `json:"push_status"`
}

//GoodsInsertReq 商品详情，商品添加
type GoodsInsertReq struct {
	GoodsName           string       `p:"goods_name" v:"goods_name@required|length:1,50#请输入商品名称|长度为1到50个字" json:"goods_name"`
	GoodsDes            string       `p:"goods_des"  json:"goods_des"`
	ProducingArea       string       `p:"producing_area" v:"producing_area@required#请输入产地" json:"producing_area"`
	DeliverArea         string       `p:"deliver_area" v:"deliver_area@required#请输入发货地" json:"deliver_area"`
	Unit                string       `p:"unit" v:"unit@required#请输入单位" json:"unit"`
	GoodsBrand          string       `p:"goods_brand" v:"goods_brand@required#请输入品牌" json:"goods_brand"`
	BrandId             int          `json:"brand_id"`
	WebUrl              string       `json:"web_url"`
	OutGoodsId          int          `json:"out_goods_id"`
	Price               int          `p:"price" json:"price"`
	JsPrice             int          `p:"js_price" json:"js_price"`
	ScPrice             int          `p:"sc_price" json:"sc_price"`
	GoodsNowStock       int          `json:"stock"`
	DefaultImage        string       `json:"default_image"`
	Description         string       `p:"description" v:"description@required#请输入商品详情" json:"description"`
	CategoryId          int          `p:"category_id" v:"category_id@required|min:1#请输入分类id" json:"category_id"`
	CategoryThreeId     int          `json:"category_three_id"`
	CategoryThreeName   string       `json:"category_three_name"`
	CategorySecondId    int          `json:"category_second_id"`
	CategorySecondName  string       `json:"category_second_name"`
	CategoryFirstId     int          `json:"category_first_id"`
	CategoryFirstName   string       `json:"category_first_name"`
	Weight              float64      `json:"weight"`
	FreightId           int          `p:"freight_id" v:"freight_id@required|min:1#请选择运费模板" json:"freight_id"`
	FreightName         string       `json:"freight_name"`
	AftersaleTime       int          `p:"aftersale_time" d:"7" v:"aftersale_time@in:7,15,30#售后时长可选范围 7天，15天，30天" json:"aftersale_time"`
	DelayCompensate     int          `p:"delay_compensate" d:"48" v:"delay_compensate@in:24, 48#延期时间可选范围 24,48小时" json:"delay_compensate"`
	Stags               string       `json:"stags"`
	IsOn                int          `p:"is_on" d:"1" json:"is_on"`
	Imgs                []string     `json:"imgs"`
	Specs               []Specs      `json:"specs"`
	SpecsGroup          []SpecsGroup `json:"specs_group"`
	ProfitRate          float64      `json:"profit_rate"`
	SellerId            int          `json:"seller_id"`
	ChannelId           int          `json:"channel_id"`
	SsoId               int          `json:"sso_id"`
	Submit              int          `json:"submit"`
	GoodsId             int          `json:"goods_id"`
	StoreName           string       `json:"store_name"`
	IsOnsale            int          `json:"is_onsale"`
	UpOnsale            int          `json:"up_onsale"`
	OperationLog        []StSysLog   `json:"operation_log"`
	IsImport            int          `json:"-"`
	Type                int          `json:"type" d:"1"` //1编辑 2不下架编辑
	PushStatus          int          `json:"push_status"`
	PlatformCheckStatus int          `json:"platform_check_status"`
	Params              []Param      `json:"params"`
	Video               string       `json:"video"`
	IsOneSpec           int          `json:"is_onespec"`
}

type StSysLog struct {
	Id          uint   `orm:"id,primary"   json:"id"`           //
	SellerId    int    `orm:"seller_id"    json:"seller_id"`    // 商户id
	GoodsId     int    `orm:"goods_id"     json:"goods_id"`     // 商品id
	UserId      int    `orm:"user_id"      json:"user_id"`      // 管理员id
	UserName    string `orm:"user_name"    json:"user_name"`    // 管理员姓名
	Type        int    `orm:"type"         json:"type"`         // 1备注2审核通过3审核拒绝
	Content     string `orm:"content"      json:"content"`      // 内容
	CreatedTime int    `orm:"created_time" json:"created_time"` // 操作时间
}

//商品参数
type Param struct {
	Id    int    `json:"id"`
	Title string `json:"title"`
	Value string `json:"value"`
}

//商品规格
type Specs struct {
	Id        int         `json:"id"`
	SpecName  string      `p:"spec_name" v:"spec_name@required#请输入规格名称" json:"spec_name"`
	SpecValue []SpecValue `json:"spec_value"`
}
type SpecValue struct {
	Id         int    `json:"id"`
	Img        string `json:"img"`
	Value      string `p:"value" v:"value@required#请输入规格值" json:"value"`
	SpecNameId int    `json:"spec_name_id"`
}
type SpecsGroup struct {
	Id            int      `json:"id"`
	SpecValues    []string `json:"spec_values"`
	GoodsNowStock int      `json:"stock"`
	JsPrice       int      `p:"js_price" v:"js_price@min:0#请输入sku指导售价" json:"js_price"`
	Price         int      `p:"price" v:"price@min:0#请输入sku指导售价" json:"price"`
	ScPrice       int      `p:"sc_price" v:"sc_price@min:0#请输入sku市场价" json:"sc_price"`
	Weight        float64  `json:"weight"`
	OutOptionId   int      `json:"out_option_id"`
	Thumb         string   `json:"thumb"`
	ProfitRate    float64  `json:"profit_rate"`
}

type GetStock struct {
	GoodsId int `json:"goods_id"`
	SkuId   int `json:"sku_id"`
	Stock   int `json:"stock"`
}
